Module org.refcodes.command
Package org.refcodes.command
Interface UndoableAccessor<CTX,R,E extends Exception>
- Type Parameters:
CTX- the generic typeR- the generic typeE- the element type
- All Known Subinterfaces:
UndoableAccessor.UndoableProperty<CTX,R,E>
- All Known Implementing Classes:
NoExceptionAvailableRuntimeException,NoResultAvailableRuntimeException,NotUndoableRuntimeException,NotYetExecutedRuntimeException
public interface UndoableAccessor<CTX,R,E extends Exception>
Provides an accessor for a command property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceUndoableAccessor.UndoableBuilder<CTX,R,E extends Exception,B extends UndoableAccessor.UndoableBuilder<CTX,R,E,B>>Provides a builder method for a name property returning the builder for applying multiple build operations.static interfaceUndoableAccessor.UndoableMutator<CTX,R,E extends Exception>Provides a mutator for a undoable property.static interfaceUndoableAccessor.UndoableProperty<CTX,R,E extends Exception>Provides a undoable property. -
Method Summary
Modifier and Type Method Description Undoable<CTX,R,E>getUndoable()Retrieves the undoable from the undoable property.
-
Method Details
-
getUndoable
Retrieves the undoable from the undoable property.- Returns:
- The undoable stored by the undoable property.
-