Uses of Interface
org.refcodes.command.Undoable
-
Uses of Undoable in org.refcodes.command
Classes in org.refcodes.command that implement UndoableModifier and TypeClassDescriptionclassAbstractUndoable<CTX,RET, E extends Exception> TheAbstractUndoableimplements theUndoableinterface.Fields in org.refcodes.command declared as UndoableModifier and TypeFieldDescriptionprotected UndoableCommandRuntimeException.CommandCommandRuntimeException._commandMethods in org.refcodes.command that return UndoableModifier and TypeMethodDescriptionCommandRuntimeException.CommandCommandRuntimeException.getUndoable()Retrieves the undoable from the undoable property.UndoableAccessor.getUndoable()Retrieves the undoable from the undoable property.UndoableAccessor.UndoableProperty.letUndoable(Undoable<CTX, R, E> aUndoable) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenUndoable(setter) as ofUndoableAccessor.UndoableMutator.setUndoable(Undoable)and returns the very same value (getter).Methods in org.refcodes.command with parameters of type UndoableModifier and TypeMethodDescriptionUndoableAccessor.UndoableProperty.letUndoable(Undoable<CTX, R, E> aUndoable) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenUndoable(setter) as ofUndoableAccessor.UndoableMutator.setUndoable(Undoable)and returns the very same value (getter).voidUndoableAccessor.UndoableMutator.setUndoable(Undoable<CTX, R, E> aCommand) Sets the undoable for the undoable property.UndoableAccessor.UndoableBuilder.withUndoable(Undoable<CTX, R, E> aCommand) Sets the undoable for the undoable property.Constructors in org.refcodes.command with parameters of type UndoableModifierConstructorDescriptionCommandCommandRuntimeException(String aMessage, Undoable aCommand) Instantiates the classCommandRuntimeException.CommandCommandRuntimeException.CommandCommandRuntimeException(String aMessage, Undoable aCommand, String aErrorCode) Instantiates the classCommandRuntimeException.CommandCommandRuntimeException.CommandCommandRuntimeException(String aMessage, Undoable aCommand, Throwable aCause) Instantiates the classCommandRuntimeException.CommandCommandRuntimeException.CommandCommandRuntimeException(String aMessage, Undoable aCommand, Throwable aCause, String aErrorCode) Instantiates the classCommandRuntimeException.CommandCommandRuntimeException.CommandCommandRuntimeException(Undoable aCommand, Throwable aCause) Instantiates the classCommandRuntimeException.CommandCommandRuntimeException.CommandCommandRuntimeException(Undoable aCommand, Throwable aCause, String aErrorCode) Instantiates the classCommandRuntimeException.CommandCommandRuntimeException.NoExceptionAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand) Instantiates the classNoExceptionAvailableRuntimeException.NoExceptionAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, String aErrorCode) Instantiates the classNoExceptionAvailableRuntimeException.NoExceptionAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNoExceptionAvailableRuntimeException.NoExceptionAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNoExceptionAvailableRuntimeException.NoExceptionAvailableRuntimeException(Throwable aCause, Undoable<?, ?, ?> aCommand, String aErrorCode) Instantiates the classNoExceptionAvailableRuntimeException.NoExceptionAvailableRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNoExceptionAvailableRuntimeException.NoResultAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand) Instantiates the classNoResultAvailableRuntimeException.NoResultAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, String aErrorCode) Instantiates the classNoResultAvailableRuntimeException.NoResultAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNoResultAvailableRuntimeException.NoResultAvailableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNoResultAvailableRuntimeException.NoResultAvailableRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNoResultAvailableRuntimeException.NoResultAvailableRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNoResultAvailableRuntimeException.NotUndoableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand) Instantiates the classNotUndoableRuntimeException.NotUndoableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, String aErrorCode) Instantiates the classNotUndoableRuntimeException.NotUndoableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNotUndoableRuntimeException.NotUndoableRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNotUndoableRuntimeException.NotUndoableRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNotUndoableRuntimeException.NotUndoableRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNotUndoableRuntimeException.NotYetExecutedRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand) Instantiates the classNotYetExecutedRuntimeException.NotYetExecutedRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, String aErrorCode) Instantiates the classNotYetExecutedRuntimeException.NotYetExecutedRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNotYetExecutedRuntimeException.NotYetExecutedRuntimeException(String aMessage, Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNotYetExecutedRuntimeException.NotYetExecutedRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause) Instantiates the classNotYetExecutedRuntimeException.NotYetExecutedRuntimeException(Undoable<?, ?, ?> aCommand, Throwable aCause, String aErrorCode) Instantiates the classNotYetExecutedRuntimeException.