| Modifier and Type | Interface | Description |
|---|---|---|
interface |
Undoable<CTX,RET,E extends Exception> |
| Modifier and Type | Class | Description |
|---|---|---|
class |
AbstractCommand<CTX,RET,E extends Exception> |
The
AbstractCommand implements the Undoable interface. |
class |
AbstractUndoable<CTX,RET,E extends Exception> |
The
AbstractUndoable implements the Undoable interface. |
| Modifier and Type | Method | Description |
|---|---|---|
Command<CTX,R,E> |
CommandAccessor.getCommand() |
Retrieves the command from the command property.
|
default Command<CTX,R,E> |
CommandAccessor.CommandProperty.letCommand(Command<CTX,R,E> aCommand) |
This method stores and passes through the given argument, which is
very useful for builder APIs: Sets the given
Command (setter)
as of CommandAccessor.CommandMutator.setCommand(Command) and returns the very same value
(getter). |
| Modifier and Type | Method | Description |
|---|---|---|
default Command<CTX,R,E> |
CommandAccessor.CommandProperty.letCommand(Command<CTX,R,E> aCommand) |
This method stores and passes through the given argument, which is
very useful for builder APIs: Sets the given
Command (setter)
as of CommandAccessor.CommandMutator.setCommand(Command) and returns the very same value
(getter). |
void |
CommandAccessor.CommandMutator.setCommand(Command<CTX,R,E> aCommand) |
Sets the command for the command property.
|
B |
CommandAccessor.CommandBuilder.withCommand(Command<CTX,R,E> aCommand) |
Sets the command for the command property.
|
Copyright © 2021. All rights reserved.