| Modifier and Type | Method | Description |
|---|---|---|
Worker<CTX,E> |
WorkerAccessor.getWorker() |
Retrieves the worker from the worker property.
|
default Worker<CTX,E> |
WorkerAccessor.WorkerProperty.letWorker(Worker<CTX,E> aWorker) |
This method stores and passes through the given argument, which is
very useful for builder APIs: Sets the given
Worker (setter)
as of WorkerAccessor.WorkerMutator.setWorker(Worker) and returns the very same value
(getter). |
| Modifier and Type | Method | Description |
|---|---|---|
default Worker<CTX,E> |
WorkerAccessor.WorkerProperty.letWorker(Worker<CTX,E> aWorker) |
This method stores and passes through the given argument, which is
very useful for builder APIs: Sets the given
Worker (setter)
as of WorkerAccessor.WorkerMutator.setWorker(Worker) and returns the very same value
(getter). |
void |
WorkerAccessor.WorkerMutator.setWorker(Worker<CTX,E> aCommand) |
Sets the worker for the worker property.
|
B |
WorkerAccessor.WorkerBuilder.withWorker(Worker<CTX,E> aCommand) |
Sets the worker for the worker property.
|
Copyright © 2021. All rights reserved.