| Class | Description |
|---|---|
| AbstractCommand |
The
AbstractCommand implements the Undoable interface. |
| Command | |
| CommandAccessor |
Provides an accessor for a command property.
|
| CommandAccessor.CommandBuilder |
Provides a builder method for a name property returning the builder for
applying multiple build operations.
|
| CommandAccessor.CommandMutator |
Provides a mutator for a command property.
|
| CommandRuntimeException |
The Class CommandRuntimeException.
|
| NotUndoableRuntimeException |
The Class NotUndoableRuntimeException.
|
| Undoable | |
| UndoableAccessor |
Provides an accessor for a command property.
|
| UndoableAccessor.UndoableBuilder |
Provides a builder method for a name property returning the builder for
applying multiple build operations.
|
| UndoableAccessor.UndoableMutator |
Provides a mutator for a undoable property.
|
| Worker | |
| WorkerAccessor |
Provides an accessor for a command property.
|
| WorkerAccessor.WorkerBuilder |
Provides a builder method for a name property returning the builder for
applying multiple build operations.
|
| WorkerAccessor.WorkerMutator |
Provides a mutator for a worker property.
|
Copyright © 2021. All rights reserved.